<?php
/**
 * Created by PhpStorm.
 * User: phillipesilva
 * Date: 16/03/2016
 * Time: 11:24
 */

namespace Service;

use Doctrine\ORM\EntityManager;
use Util\Messages;
use Zeedhi\DevOps\Model\Configurationmanager\Entities\DeployPackage;
use Zeedhi\DevOps\Model\Servermanager\Entities\DeployServer;
use Zeedhi\DevOps\Model\Projectmanagement\Entities\Attachment;
use Zeedhi\DevOps\Util\Environment;
use Zeedhi\DevOps\Util\Utilities;
use Factory\Deploy as DeployFactory;
use Factory\DeployPackage as DeployPackageFactory;
use Factory\DeployServer as DeployServerFactory;
use Zeedhi\DevOps\Model\Configurationmanager\Entities\Deploy as DeployEntity;
use Zeedhi\DevOps\Model\Servermanager\Repositories as ServerRepositories;
use Zeedhi\DevOps\Model\Configurationmanager\Repositories as ConfigurationRepositories;
use Zeedhi\Framework\Log\Exception;
use Util\Mail\Core\SmtpMail;

class Deploy {
    /** @var EntityManager $entityManager */
    protected $entityManager;
    /** @var DeployFactory $deployFactory */
    protected $deployFactory;
    /** @var DeployPackageFactory $deployPackageFactory */
    protected $deployPackageFactory;
    /** @var DeployServerFactory $deployServerFactory */
    protected $deployServerFactory;
    /** @var ServerRepositories\DeployServer $deployServerRepository */
    protected $deployServerRepository;
    /** @var ConfigurationRepositories\Deploy $deployRepository */
    protected $deployRepository;
    /** @var ConfigurationmanagerRepository\DeployPackage $deployPackageRepository */
    protected $deployPackageRepository;
    /** @var ProjectmanagementRepositories\Attachment $attachmentRepository */
    protected $attachmentRepository;
    /**
     * @var Environment
     */
    private $environment;
    
    const DEPLOY_STATUS = array(
        'A' => 'Parcial',
        'D' => 'Aplicado',
        'P' => 'Pendente',
        'E' => 'Erro',
        'R' => 'Removido'
    );

    /**
     * @param EntityManager $entityManager
     * @param Environment $environment
     * @param DeployFactory $deployFactory
     * @param DeployPackageFactory $deployPackageFactory
     * @param DeployServerFactory $deployServerFactory
     */
    public function __construct(EntityManager $entityManager, Environment $environment, DeployFactory $deployFactory,
                                DeployPackageFactory $deployPackageFactory, DeployServerFactory $deployServerFactory) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->deployFactory = $deployFactory;
        $this->deployPackageFactory = $deployPackageFactory;
        $this->deployServerFactory = $deployServerFactory;
        $this->deployRepository = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Deploy');
        $this->deployServerRepository = $this->entityManager->getRepository(Utilities::SERVER_MANAGER_ENTITY_DIR . 'DeployServer');
        $this->deployPackageRepository = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'DeployPackage');
        $this->attachmentRepository = $this->entityManager->getRepository(Utilities::PROJECT_MANAGEMENT_ENTITY_DIR . 'Attachment');
    }

    /**
     * @param $productId
     * @param $conditions
     * @return array
     */
    public function findDeploy($productId, $conditions, $page = null, $pageSize = null) {
        $limit = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        foreach ($conditions as $key => &$filter) {
            $name = $filter['columnName'];
            if($name == 'ID' ){
                unset($conditions[$key]);
            }
            if($name == 'DEPLOY_ID'){
                $filter['columnName'] = 'ID';
            }
        }
        $filters = Utilities::createQueryFiltered($conditions);
        /** @var \Zeedhi\DevOps\Model\Configurationmanager\Repositories\Deploy $deployRepository */
        $deployRepository = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Deploy');
        $organizationId = $this->environment->getOrganizationId();
        $deployRegisters = $this->deployRepository->getDeploy($productId, $filters,$organizationId, $limit, $offset);

        foreach($deployRegisters as &$deploy) {
            if($deploy['SERVER']) {
                $maxDateByServers = $deployRepository->getMaxDeployDateByServers($productId, $deploy['SERVER']);
                $deploy['MAX_DEPLOY_DATE'] = $maxDateByServers[0]["MAX_DATE"];
            }
            if($deploy['SERVER']) {
                $deploy['SERVER'] = Utilities::setSelectMultiInQuery($deploy['SERVER']);
            }
            if($deploy['PACKAGE']) {
                $deploy['PACKAGE'] = Utilities::setSelectMultiInQuery($deploy['PACKAGE']);
            }
        }

        return $deployRegisters;
    }

    /**
     * @param $productId
     * @return array
     */
    public function findProductVersionWithConcatVersion($productId, $page, $pageSize, $filter = array()) {
        /** @var \Zeedhi\DevOps\Model\Devops\Repositories\ProductVersion $productVersionRepository */
        $filterString = Utilities::createQueryFiltered($filter);
        $productVersionRepository = $this->entityManager->getRepository(Utilities::DEVOPS_ENTITY_DIR . 'ProductVersion');
        $organizationId = $this->environment->getOrganizationId();
        $limit = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $productVersionRepository->findProductVersionWithConcatVersionByProduct($productId,$organizationId, $limit, $offset, $filterString);
    }

    /**
     * @param $deployId
     * @param $date
     * @param $isActive
     * @param $name
     * @param $packages
     * @param $pathBkp
     * @param $productId
     * @param $productVersionId
     * @param $servers
     * @param $status
     * @throws \Exception
     */
    public function saveDeploy($deployId, $date, $isActive, $name, $packages, $pathBkp,
                               $productId, $productVersionId, $servers, $status, $devopsUserId = null) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try {
            /** Integration CP */
            if($devopsUserId){
                $this->environment->setCurrentUserId($devopsUserId);
            }
            /** @var \Zeedhi\DevOps\Model\Configurationmanager\Entities\Deploy $deploy */
            if($deployId) {
                $deploy = $this->entityManager->find(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Deploy', $deployId);
            } else {
                $deploy = new DeployEntity();
            }
            /** @var \Zeedhi\DevOps\Model\Configurationmanager\Entities\Product $product */
            $product = $this->entityManager->find(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Product', $productId);
            /** @var \Zeedhi\DevOps\Model\Devops\Entities\ProductVersion $productVersion */
            $productVersion = $this->entityManager->find(Utilities::DEVOPS_ENTITY_DIR . 'ProductVersion', $productVersionId);

            if($date) {
                $date = \DateTime::createFromFormat('d/m/Y H:i:s', $date);
            }
            $deploy = $this->deployFactory->setDeployRecords($deploy, $product, $productVersion, $name, $isActive,
                $date, $status, $pathBkp);
            $this->entityManager->persist($deploy);

            $this->updateDeployPackages($packages, $deploy);
            $this->updateDeployServers($servers, $deploy);
            $this->entityManager->flush();

            $this->updateStatusDeployAfterSave($deploy);
            
            $this->entityManager->flush();
            $connection->commit();
            return array('ID' => $deploy->getId());
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    /**
     * @param $packages
     * @param $deploy
     */
    private function updateDeployPackages($packages, $deploy)
    {
        foreach ($packages as $package) {
            /** @var \Zeedhi\DevOps\Model\Devops\Entities\ProductVersionPackages $productVersionPackages */
            $productVersionPackages = $this->entityManager->find(Utilities::DEVOPS_ENTITY_DIR . 'ProductVersionPackages', $package);
            /** @var \Zeedhi\DevOps\Model\Configurationmanager\Entities\DeployPackage $package */
            $deployPackage = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'DeployPackage')
                ->findOneBy(array('deploy' => $deploy, 'productVersionPackage' => $package));
            if (empty($deployPackage)) {
                $deployPackage = new DeployPackage();
                $deployPackage = $this->deployPackageFactory->setDeployPackageRecords($deployPackage, $deploy, $productVersionPackages);
                $this->entityManager->persist($deployPackage);
            }
        }

        $deployPackages = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'DeployPackage')
            ->findBy(array('deploy' => $deploy));
        foreach ($deployPackages as $package) {
            /** @var \Zeedhi\DevOps\Model\Devops\Entities\ProductVersionPackages $prodPackage */
            $prodPackage = $this->entityManager->find(Utilities::DEVOPS_ENTITY_DIR . 'ProductVersionPackages', $package->getProductVersionPackage()->getId());
            if (!in_array($prodPackage->getId(), $packages)) {
                $this->entityManager->remove($package);
            }
        }
    }

    /**
     * @param $productServerIds
     * @param $deploy
     */
    private function updateDeployServers($productServerIds, $deploy)
    {
        foreach ($productServerIds as $productServerId) {
            /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\ProductServer $prodServer */
            $prodServer = $this->entityManager->find(Utilities::SERVER_MANAGER_ENTITY_DIR . 'ProductServer', $productServerId);
            /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\DeployServer $deployServer */
            $deployServer = $this->entityManager->getRepository(Utilities::SERVER_MANAGER_ENTITY_DIR . 'DeployServer')
                ->findOneBy(array('deploy' => $deploy, 'productServer' => $prodServer));
            if (empty($deployServer)) {
                $deployServer = new DeployServer();
                $deployServer = $this->deployServerFactory->setDeployServerRecords($deployServer, $deploy, $prodServer);
                $this->entityManager->persist($deployServer);
            }
        }

        $deployServers = $this->entityManager->getRepository(Utilities::SERVER_MANAGER_ENTITY_DIR . 'DeployServer')
            ->findBy(array('deploy' => $deploy));
        $deployedServersString = '';
        foreach ($deployServers as $depServer) {
            /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\DeployServer $depServer */
            if (!in_array($depServer->getProductServer()->getId(), $productServerIds)) {
                if($depServer->getStatus() == DeployEntity::DEPLOYED_DEPLOY_STATUS) {
                    $deployedServersString .= '"'.$depServer->getProductServer()->getServer()->getName().'"<br/>';
                }else {
                    $this->entityManager->remove($depServer);
                }
            }
        }
        if(!empty($deployedServersString)) {
            throw new Exception(Messages::ERR_REMOVE_DEPLOYED_SERVER.$deployedServersString);
        }
    }

    private function updateStatusDeployAfterSave(DeployEntity $deploy) {
        $deployServers = $this->deployServerRepository->findBy(array('deploy' => $deploy));
        $allDeployedServers = true;
        /** @var DeployServer $deployServer */
        foreach ($deployServers as $deployServer) {
            if($deployServer->getStatus() != DeployEntity::DEPLOYED_DEPLOY_STATUS) {
                $allDeployedServers = false;
            }
        }
        if($allDeployedServers) {
            $deploy->setStatus(DeployEntity::DEPLOYED_DEPLOY_STATUS);
            $deploy->setDeployDate(new \DateTime());
            $this->entityManager->persist($deploy);
        }
    }

    /**
     * @param $deployId
     * @throws \Exception
     */
    public function removeDeploy($deployId) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try {
            /** @var \Zeedhi\DevOps\Model\Configurationmanager\Entities\Deploy $deploy */
            $deploy = $this->deployRepository->find($deployId);
            
            $deployServers = $this->deployServerRepository->findBy(array('deploy' => $deploy));
            foreach ($deployServers as $deployServer) {
                $this->entityManager->remove($deployServer);
            }
            
            $deployPackages = $this->deployPackageRepository->findBy(array('deploy' => $deploy));
            foreach ($deployPackages as $deployPackage) {
                $this->entityManager->remove($deployPackage);
            }
            
            $attachments = $this->attachmentRepository->findBy(array('deploy' => $deploy));
            foreach ($attachments as $attachment) {
                $this->entityManager->remove($attachment);
            }       

            $this->entityManager->remove($deploy);
            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }
    
    public function sendMailDeployInformation($deploy, $productServerId, $status)
    {
        try {
            
            $name = Utilities::getSmtpName();
            $host = Utilities::getSmtpHost();
            $user = Utilities::getSmtpUsername();
            $password = Utilities::getSmtpPassword();
            $connectionClass = Utilities::getSmtpConnectionClass();
            
            $emails = Utilities::getSendEmailsAfterDeploy();
            $date   = new \DateTime();
            
            $from = Utilities::getSmtpUsername();
            $subject = 'Deploy executado através do Devops (Produto: ' . $deploy->getProduct()->getName() . ')';
            $productVersion = $deploy->getProductVersion();
            $version =  $productVersion->getVersion() . '.' .  $productVersion->getRevision() . '.' .  $productVersion->getBuild();
            /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\ProductServer $productServer */
            $productServer = $this->entityManager->find(Utilities::SERVER_MANAGER_ENTITY_DIR . 'ProductServer', $productServerId);
            
            foreach (explode(',', $emails) as $email) {
                $body = "<strong><li>Id do Deploy: </strong> " . $deploy->getId() . "</li>
                         <strong><li>Produto: </strong> " . $deploy->getProduct()->getName() . "</li>
                         <strong><li>Versão: </strong> " . $version . "</li>
                         <strong><li>Servidor:</strong> " . $productServer->getServer()->getName() . ' (' . $productServer->getPath() . ')' . "</li>
                         <strong><li>Status: </strong> " . self::DEPLOY_STATUS[$status] . "</li>
                         <strong><li>Data: </strong>" . $date->format('d/m/Y H:i') . "</li>
                         <strong><li>Operador:</strong> " . $this->environment->getCurrentUserName() . "</li>";
                
                $smtp = new SmtpMail($name, $host, $user, $password, $connectionClass);
                $body = utf8_decode($body);
                $smtp->sendHtmlEmail($from, $email, $subject, $body);
            }
            
        } catch (\Exception $e) {}
    }

    /**
     * @param $serverIds
     * @param $packageIds
     * @param $deployId
     * @param $deployStatus
     * @param $productServerId
     * @return array
     */
    public function getApplyDeployInformation($serverIds, $packageIds, $deployId, $deployStatus, $productServerId) {
        /** @var DeployEntity $deploy */
        $deploy = $this->deployRepository->find($deployId);
        $information = array(
            'PRODUCT_ID' => $deploy->getProduct()->getId(),
            'PACKAGE' => array(),
            'SERVER' => array()
        );
        $information = $this->setPackageInformation($packageIds, $information);
        $information = $this->setServerInformation($serverIds, $deployId, $deployStatus, $information, $productServerId);

        return $information;
    }

    public function verifyActiveServes($filters) {
        return $this->deployServerRepository->verifyActiveServers($filters);
    }

    /**
     * @param $packageIds
     * @param $information
     * @return mixed
     */
    private function setPackageInformation($packageIds, $information)
    {
        foreach ($packageIds as $package) {
            /** @var \Zeedhi\DevOps\Model\Devops\Entities\ProductVersionPackages $prodPackage */
            $prodPackage = $this->entityManager->find(Utilities::DEVOPS_ENTITY_DIR . 'ProductVersionPackages', $package);

            $information['PACKAGE'][] = array(
                'ID' => $prodPackage->getId(),
                'URL' => $prodPackage->getUrl(),
                'NAME' => $prodPackage->getName(),
                'FILE_NAME' => $prodPackage->getFileName(),
                'PATH_TO_DEPLOY' => $prodPackage->getPathToDeploy(),
                'SERVER_ID' => $prodPackage->getServer()->getId(),
                'SERVER_NAME' => $prodPackage->getServer()->getName(),
                'SERVER_EMAIL' => $prodPackage->getServer()->getWsemail()
            );
        }
        return $information;
    }

    /**
     * @param $productServerIds
     * @param $deployId
     * @param $deployStatus
     * @param $information
     * @param $productServerId
     * @return mixed
     */
    private function setServerInformation($productServerIds, $deployId, $deployStatus, $information, $productServerId)
    {
        $productServerIds = "'" . implode("', '", $productServerIds) . "'";
        if($productServerId) {
            $filterDeployServerStatus = '';
            $filterProductServer = $productServerId ? ' AND PS.ID = ' . $productServerId : '';
        } else if ($deployStatus == DeployEntity::DEPLOYED_DEPLOY_STATUS) {
            $filterDeployServerStatus = " AND DS.STATUS = 'D'";
            $filterProductServer = '';
        } else {
            $filterDeployServerStatus = " AND DS.STATUS <> 'D'";
            $filterProductServer = '';
        }
        $organizationId = $this->environment->getOrganizationId();
        $serverInfo = $this->deployServerRepository->findServerInformationDeploy($deployId, $productServerIds,
            $filterDeployServerStatus, $filterProductServer,$organizationId);
        foreach($serverInfo as $info) {
            $information['SERVER'][$info['DEPLOYMENT_ORDER']][] = $info;
        }
        $information['SERVER'] = array_values($information['SERVER']);
        return $information;
    }

    /**
     * @param $deployId
     * @param $productServerId
     * @param $status
     * @param $isDeployServerOnly
     * @param $deployBkpPath
     * @throws \Exception
     */
    public function saveDeployServer($deployId, $productServerId, $status, $isDeployServerOnly, $deployBkpPath) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try {
            /** @var \Zeedhi\DevOps\Model\Configurationmanager\Entities\Deploy $deploy */
            $deploy = $this->entityManager->find(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Deploy', $deployId);
            /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\ProductServer $prodServer */
            $prodServer = $this->entityManager->find(Utilities::SERVER_MANAGER_ENTITY_DIR . 'ProductServer', $productServerId);
            /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\DeployServer $deployServer */
            $deployServer = $this->entityManager->getRepository(Utilities::SERVER_MANAGER_ENTITY_DIR . 'DeployServer')
                ->findOneBy(array('deploy' => $deploy, 'productServer' => $prodServer));

            $deployServer = $this->deployServerFactory->setDeployServerRecords($deployServer, $deploy, $prodServer, $status, $deployServer->getDeploymentOrder());
            if($status == DeployEntity::DEPLOYED_DEPLOY_STATUS) {
                $date = new \DateTime();
                $deployServer->setDeployDate($date);
            }
            $this->entityManager->persist($deployServer);
            $this->entityManager->flush();

            if($isDeployServerOnly) {
                $this->updateDeployStatus($deploy, $deployServer, $deployBkpPath);
            }
            
            if($status != 'P'){
                $this->sendMailDeployInformation($deploy, $productServerId, $status);
            }
            
            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    /**
     * @param $productServerId
     * @param $currentDeployId
     * @param $removedPaths
     * @param $backupLimit
     * @param $productId
     * @throws \Doctrine\DBAL\ConnectionException
     * @throws \Exception
     */
    public function inactiveDeploysRemoved($productServerId, $removedPaths, $currentDeployId, $backupLimit, $productId) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try {
            if($backupLimit == 0) {
                $oldServers = $this->deployServerRepository->findOldDeployServerToInactive($productId, $productServerId, $currentDeployId);
                foreach($oldServers as $oldServer) {
                    /** @var DeployServer $deployServer */
                    $deployServer = $this->deployServerRepository->find($oldServer['DEPLOY_SERVER_ID']);
                    $deployServer->setIsActive(DeployEntity::IS_ACTIVE_NO);
                    $this->entityManager->persist($deployServer);
                    $this->inactiveDeploy($oldServer['DEPLOY_ID'], $deployServer);
                }
            }

            foreach($removedPaths as $path) {
                $path = explode('DEP_', $path);
                $path = explode('_', $path[1]);
                $deployId = $path[0];
                if($deployId != $currentDeployId) {
                    /** @var DeployServer $deployServer */
                    $deployServer = $this->deployServerRepository->findOneBy(array('deploy' => $deployId,
                        'productServer' => $productServerId));
                    $deployServer->setIsActive(DeployEntity::IS_ACTIVE_NO);
                    $this->entityManager->persist($deployServer);
                    $this->inactiveDeploy($deployId, $deployServer);
                }
            }

            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    /**
     * @param $deploy
     * @param $deployServer
     * @param $deployBkpPath
     */
    private function updateDeployStatus($deploy, $deployServer, $deployBkpPath)
    {
        $validationStatus = array('DEPLOYED' => array(), 'ERROR' => array(), 'PENDING' => array());
        $deploysStatus = DeployEntity::PENDING_DEPLOY_STATUS;
        $deployServers = $this->entityManager->getRepository(Utilities::SERVER_MANAGER_ENTITY_DIR . 'DeployServer')
            ->findBy(array('deploy' => $deploy));
        /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\DeployServer $deployServer */
        /** @var \Zeedhi\DevOps\Model\Servermanager\Entities\DeployServer $depServer */
        foreach ($deployServers as $depServer) {
            if ($depServer->getStatus() == DeployEntity::ERROR_DEPLOY_STATUS && $depServer->getId() != $deployServer->getId()) {
                array_push($validationStatus['ERROR'], $depServer->getId());
            } else if ($depServer->getStatus() == DeployEntity::PENDING_DEPLOY_STATUS && $depServer->getId() != $deployServer->getId()) {
                array_push($validationStatus['PENDING'], $depServer->getId());
            } else if ($depServer->getStatus() == DeployEntity::DEPLOYED_DEPLOY_STATUS && $depServer->getId() != $deployServer->getId()) {
                array_push($validationStatus['DEPLOYED'], $depServer->getId());
            }
        }

        if ($deployServer->getStatus() == DeployEntity::ERROR_DEPLOY_STATUS) {
            array_push($validationStatus['ERROR'], $deployServer->getId());
        } else if ($deployServer->getStatus() == DeployEntity::DEPLOYED_DEPLOY_STATUS) {
            array_push($validationStatus['DEPLOYED'], $deployServer->getId());
        } else if ($deployServer->getStatus() == DeployEntity::PENDING_DEPLOY_STATUS) {
            array_push($validationStatus['PENDING'], $deployServer->getId());
        }

        /** @var \Zeedhi\DevOps\Model\Configurationmanager\Entities\Deploy $deploy */
        if (empty($validationStatus['ERROR']) && empty($validationStatus['PENDING'])) {
            $deploysStatus = DeployEntity::DEPLOYED_DEPLOY_STATUS;
            $deploy->setDeployDate(new \DateTime());
            $deploy->setPathBackup($deployBkpPath);
        } else if (!empty($validationStatus['ERROR'])) {
            $deploysStatus = DeployEntity::ERROR_DEPLOY_STATUS;
            $deploy->setDeployDate(null);
            $deploy->setPathBackup(null);
        } else if (!empty($validationStatus['DEPLOYED']) && !empty($validationStatus['PENDING'])) {
            $deploysStatus = DeployEntity::PARTIAL_DEPLOY_STATUS;
            $deploy->setDeployDate(null);
            $deploy->setPathBackup(null);
        }
        $deploy->setStatus($deploysStatus);
        $this->entityManager->persist($deploy);
    }

    /**
     * @param $deployId
     * @param $isActive
     * @return null|string
     */
    public function validateActiveInactiveDeploy($deployId, $isActive)
    {
        $result = null;
        /** @var DeployEntity $deploy */
        $deploy = $this->deployRepository->find($deployId);
        if ($deploy) {
            $updateIsActive = $isActive != $deploy->getIsActive();
            if ($updateIsActive && $deploy->getStatus() == DeployEntity::DEPLOYED_DEPLOY_STATUS) {
                if ($isActive == DeployEntity::IS_ACTIVE_YES) {
                    $result = 'ACTIVATE';
                } else {
                    $result = 'INACTIVATE';
                }
            }
        }
        return $result;
    }

    /**
     * @param $deployId
     * @param DeployServer $deployServer
     */
    private function inactiveDeploy($deployId, DeployServer $deployServer)
    {
        $allDeployServers = $this->deployServerRepository->findBy(array('deploy' => $deployId));
        $isInactiveDeploy = true;
        /** @var DeployServer $aDeployServer */
        foreach ($allDeployServers as $aDeployServer) {
            if ($aDeployServer->getIsActive() == DeployEntity::IS_ACTIVE_YES &&
                $aDeployServer->getId() != $deployServer->getId()
            ) {
                $isInactiveDeploy = false;
            }
        }

        if ($isInactiveDeploy) {
            /** @var DeployEntity $deploy */
            $deploy = $this->deployRepository->find($deployId);
            $deploy->setIsActive(DeployEntity::IS_ACTIVE_NO);
            $this->entityManager->persist($deploy);
        }
    }
    
    public function findLastDeployProduct($productId, $productServerId)
    {
        return $this->deployRepository->findLastDeployProduct($productId, $productServerId);
    }
    
    /**
     * @param $log
     * @return array
     */
    public function findDeployErrors($conditions, $log) {
        $filters = Utilities::createQueryFiltered($conditions);
        $errors = $this->deployRepository->getKnowErrors($filters);
        $knowErrors = [];

        foreach ($errors as $error) {
            if(strpos($log, $error["DESCRIPTION"])){
                array_push($knowErrors, $error);
            };
        }

        return $knowErrors;
    }

}