/* Tabela ITEMPRECODIA: TABELA DE PREOS DE ITEM POR DIA*/
/* Descrio: A trigger insere registros na tabela LOGOPERAVND a partir de alteraes na tabela ITEMPRECODIA */
/* Objetivo: Gerar um log que vai registrar as alteraes na ITEMPRECODIA,
             utilizando a tabela de Logs de Operaes do VND*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_VND_ITEMPRECODIA' AND
                 TYPE   = 'TR' 	               AND
	              U.UID  = O.UID           AND
	              U.NAME = USER)
DROP TRIGGER LOG_VND_ITEMPRECODIA
GO

CREATE TRIGGER LOG_VND_ITEMPRECODIA
ON ITEMPRECODIA
FOR INSERT, UPDATE, DELETE
AS
  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(40);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_ID_COMANDO    VARCHAR(1);

  DECLARE @V_NEW_CDFILIAL            varchar(4);
  DECLARE @V_NEW_CDTABEPREC          varchar(3);
  DECLARE @V_NEW_DTINIVGPREC         datetime;
  DECLARE @V_NEW_CDPRODUTO           varchar(10);
  DECLARE @V_NEW_CDPRPAITABPR        varchar(10);
  DECLARE @V_NEW_NRDIASEMANPR        varchar(1);
  DECLARE @V_NEW_HRINIPRECDIA        varchar(4);
  DECLARE @V_NEW_CDTIPOCONSPD        varchar(2);
  DECLARE @V_NEW_HRFINPRECDIA        varchar(4);
  DECLARE @V_NEW_VRPRECODIA          double precision;
  DECLARE @V_NEW_IDPERVALORPR        varchar(1);
  DECLARE @V_NEW_IDDESCACREPR        varchar(1);
  DECLARE @V_NEW_DTINIVALPREC        datetime;
  DECLARE @V_NEW_DTFINVALPREC        datetime;
  DECLARE @V_NEW_DTULTATUITPD        datetime;
  DECLARE @V_NEW_IDVISUACUPOM        char(1);

  DECLARE @V_OLD_CDFILIAL            varchar(4);
  DECLARE @V_OLD_CDTABEPREC          varchar(3);
  DECLARE @V_OLD_DTINIVGPREC         datetime;
  DECLARE @V_OLD_CDPRODUTO           varchar(10);
  DECLARE @V_OLD_CDPRPAITABPR        varchar(10);
  DECLARE @V_OLD_NRDIASEMANPR        varchar(1);
  DECLARE @V_OLD_HRINIPRECDIA        varchar(4);
  DECLARE @V_OLD_CDTIPOCONSPD        varchar(2);
  DECLARE @V_OLD_HRFINPRECDIA        varchar(4);
  DECLARE @V_OLD_VRPRECODIA          double precision;
  DECLARE @V_OLD_IDPERVALORPR        varchar(1);
  DECLARE @V_OLD_IDDESCACREPR        varchar(1);
  DECLARE @V_OLD_DTINIVALPREC        datetime;
  DECLARE @V_OLD_DTFINVALPREC        datetime;
  DECLARE @V_OLD_DTULTATUITPD        datetime;
  DECLARE @V_OLD_IDVISUACUPOM        char(1);

BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @P_NMUSUARIO = @V_NMOPERADOR OUTPUT;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, ' ');

   EXEC WEBTUNNING  @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                    @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                    @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                    @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                    @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;

   DECLARE C_CURSOR CURSOR FOR
     SELECT
     'D'   ID_COMANDO,
           NULL,
           NULL,NULL,NULL,NULL,NULL,
           NULL,NULL,NULL,NULL,NULL,
           NULL,NULL,NULL,NULL,NULL,
           DELETED.CDFILIAL,
           DELETED.CDTABEPREC,
           DELETED.DTINIVGPREC,
           DELETED.CDPRODUTO,
           DELETED.CDPRPAITABPR,
           DELETED.NRDIASEMANPR,
           DELETED.HRINIPRECDIA,
           DELETED.CDTIPOCONSPD,
           DELETED.HRFINPRECDIA,           
           DELETED.VRPRECODIA,
           DELETED.IDPERVALORPR,
           DELETED.IDDESCACREPR,
           DELETED.DTINIVALPREC,
           DELETED.DTFINVALPREC,
           DELETED.DTULTATUITPD,
           DELETED.IDVISUACUPOM


     FROM
           DELETED
     WHERE     
           CDFILIAL + CDTABEPREC + CDPRODUTO + CDPRPAITABPR + NRDIASEMANPR + HRINIPRECDIA + CDTIPOCONSPD NOT IN (SELECT CDFILIAL + CDTABEPREC + CDPRODUTO + CDPRPAITABPR + NRDIASEMANPR + HRINIPRECDIA + CDTIPOCONSPD FROM INSERTED)
	   and  DTINIVGPREC NOT IN (SELECT DTINIVGPREC FROM INSERTED)
     UNION ALL

     SELECT
     'U'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDTABEPREC,
           INSERTED.DTINIVGPREC,
           INSERTED.CDPRODUTO,
           INSERTED.CDPRPAITABPR,
           INSERTED.NRDIASEMANPR,
           INSERTED.HRINIPRECDIA,
           INSERTED.CDTIPOCONSPD,
           INSERTED.HRFINPRECDIA,           
           INSERTED.VRPRECODIA,
           INSERTED.IDPERVALORPR,
           INSERTED.IDDESCACREPR,
           INSERTED.DTINIVALPREC,
           INSERTED.DTFINVALPREC,
           INSERTED.DTULTATUITPD,
           INSERTED.IDVISUACUPOM,

           DELETED.CDFILIAL,
           DELETED.CDTABEPREC,
           DELETED.DTINIVGPREC,
           DELETED.CDPRODUTO,
           DELETED.CDPRPAITABPR,
           DELETED.NRDIASEMANPR,
           DELETED.HRINIPRECDIA,
           DELETED.CDTIPOCONSPD,
           DELETED.HRFINPRECDIA,           
           DELETED.VRPRECODIA,
           DELETED.IDPERVALORPR,
           DELETED.IDDESCACREPR,
           DELETED.DTINIVALPREC,
           DELETED.DTFINVALPREC,
           DELETED.DTULTATUITPD,
           DELETED.IDVISUACUPOM

     FROM
           INSERTED,
           DELETED
     WHERE     
           DELETED.CDFILIAL     = INSERTED.CDFILIAL     AND
           DELETED.CDTABEPREC   = INSERTED.CDTABEPREC   AND
           DELETED.DTINIVGPREC  = INSERTED.DTINIVGPREC  AND 
           DELETED.CDPRODUTO    = INSERTED.CDPRODUTO    AND
           DELETED.CDPRPAITABPR = INSERTED.CDPRPAITABPR AND 
           DELETED.NRDIASEMANPR = INSERTED.NRDIASEMANPR AND
           DELETED.HRINIPRECDIA = INSERTED.HRINIPRECDIA AND
           DELETED.CDTIPOCONSPD = INSERTED.CDTIPOCONSPD
     UNION ALL

     SELECT
     'I'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDTABEPREC,
           INSERTED.DTINIVGPREC,
           INSERTED.CDPRODUTO,
           INSERTED.CDPRPAITABPR,
           INSERTED.NRDIASEMANPR,
           INSERTED.HRINIPRECDIA,
           INSERTED.CDTIPOCONSPD,
           INSERTED.HRFINPRECDIA,           
           INSERTED.VRPRECODIA,
           INSERTED.IDPERVALORPR,
           INSERTED.IDDESCACREPR,
           INSERTED.DTINIVALPREC,
           INSERTED.DTFINVALPREC,
           INSERTED.DTULTATUITPD,
           INSERTED.IDVISUACUPOM,

           NULL,NULL,NULL,NULL,NULL,
           NULL,NULL,NULL,NULL,NULL,
           NULL,NULL,NULL,NULL,NULL,
           NULL
     FROM
           INSERTED
     WHERE     
           CDFILIAL + CDTABEPREC + CDPRODUTO + CDPRPAITABPR + NRDIASEMANPR + HRINIPRECDIA + CDTIPOCONSPD NOT IN (SELECT CDFILIAL + CDTABEPREC +  CDPRODUTO + CDPRPAITABPR + NRDIASEMANPR + HRINIPRECDIA + CDTIPOCONSPD FROM DELETED)
	   and  DTINIVGPREC NOT IN (SELECT DTINIVGPREC FROM DELETED)
     OPEN C_CURSOR;
    FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
           @V_NEW_CDFILIAL,@V_NEW_CDTABEPREC,@V_NEW_DTINIVGPREC,@V_NEW_CDPRODUTO,
           @V_NEW_CDPRPAITABPR,@V_NEW_NRDIASEMANPR,@V_NEW_HRINIPRECDIA,@V_NEW_CDTIPOCONSPD,
           @V_NEW_HRFINPRECDIA,@V_NEW_VRPRECODIA,@V_NEW_IDPERVALORPR,@V_NEW_IDDESCACREPR,
           @V_NEW_DTINIVALPREC,@V_NEW_DTFINVALPREC,@V_NEW_DTULTATUITPD,@V_NEW_IDVISUACUPOM,

           @V_OLD_CDFILIAL,@V_OLD_CDTABEPREC,@V_OLD_DTINIVGPREC,@V_OLD_CDPRODUTO,
           @V_OLD_CDPRPAITABPR,@V_OLD_NRDIASEMANPR,@V_OLD_HRINIPRECDIA,@V_OLD_CDTIPOCONSPD,
           @V_OLD_HRFINPRECDIA,@V_OLD_VRPRECODIA,@V_OLD_IDPERVALORPR,@V_OLD_IDDESCACREPR,
           @V_OLD_DTINIVALPREC,@V_OLD_DTFINVALPREC,@V_OLD_DTULTATUITPD,@V_OLD_IDVISUACUPOM

    WHILE (@@FETCH_STATUS = 0) BEGIN
 
      IF @V_ID_COMANDO= 'U' /*UPDATE*/ BEGIN
		IF ISNULL(@V_NEW_CDFILIAL,'NULL') <> ISNULL(@V_OLD_CDFILIAL,'NULL') BEGIN
			SET @V_DESC   = 'Filial ' + ISNULL(@V_NEW_CDFILIAL,'');
		END;
		IF ISNULL(@V_NEW_CDTABEPREC,'NULL') <> ISNULL(@V_OLD_CDTABEPREC,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd da Tabela de Preo ' + ISNULL(@V_NEW_CDTABEPREC,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTINIVGPREC),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTINIVGPREC),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  DTINIVGPREC ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTINIVGPREC),'');
		END;
		IF ISNULL(@V_NEW_CDPRODUTO,'NULL') <> ISNULL(@V_OLD_CDPRODUTO,'NULL') BEGIN
	   	    SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Produto '+ ISNULL(@V_NEW_CDPRODUTO,'');
		END;
		IF ISNULL(@V_NEW_CDPRPAITABPR,'NULL') <> ISNULL(@V_OLD_CDPRPAITABPR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  CDPRPAITABPR ' + ISNULL(@V_NEW_CDPRPAITABPR,'' );
		END;
		IF ISNULL(@V_NEW_NRDIASEMANPR,'NULL') <> ISNULL(@V_OLD_NRDIASEMANPR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Nr do dia da Semana ' + ISNULL(@V_NEW_NRDIASEMANPR,'');
		END;
		IF ISNULL(@V_NEW_HRINIPRECDIA,'NULL') <> ISNULL(@V_OLD_HRINIPRECDIA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Hr de Inicio Promoo ' + ISNULL(@V_NEW_HRINIPRECDIA,'');
		END;
		IF ISNULL(@V_NEW_CDTIPOCONSPD,'NULL') <> ISNULL(@V_OLD_CDTIPOCONSPD,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Tipo de Consumidor ' + ISNULL(@V_NEW_CDTIPOCONSPD,'');
		END;
		IF ISNULL(@V_NEW_HRFINPRECDIA,'NULL') <> ISNULL(@V_OLD_HRFINPRECDIA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Hr de Fim Promoo ' + ISNULL(@V_NEW_HRFINPRECDIA,'');
		END;
		IF ISNULL(@V_NEW_VRPRECODIA,'NULL') <> ISNULL(@V_OLD_VRPRECODIA,'NULL') BEGIN
	        SET @V_DESC  = ISNULL(@V_DESC,'') + '  Preo produto ' + ISNULL(CONVERT(VARCHAR,@V_NEW_VRPRECODIA),'');
		END;
		IF ISNULL(@V_NEW_IDPERVALORPR,'NULL') <> ISNULL(@V_OLD_IDPERVALORPR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Id Valor ' + ISNULL(@V_NEW_IDPERVALORPR,'');
		END;
		IF ISNULL(@V_NEW_IDDESCACREPR,'NULL') <> ISNULL(@V_OLD_IDDESCACREPR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Id Desconto ' + ISNULL(@V_NEW_IDDESCACREPR,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTINIVALPREC),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTINIVALPREC),'NULL') BEGIN
	        SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt Inicio Validade ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTINIVALPREC),'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTFINVALPREC),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTFINVALPREC),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt Fim Validade ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTFINVALPREC),'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUITPD),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATUITPD),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt Ult Atu do Preo ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUITPD),'');
		END;
		IF ISNULL(@V_NEW_IDVISUACUPOM,'NULL') <> ISNULL(@V_OLD_IDVISUACUPOM,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Id Visua Desc Cupom ' + ISNULL(@V_NEW_IDVISUACUPOM,'');
		END;
        SET @V_IDTIPOOPER = '2';
      END;
      IF @V_ID_COMANDO= 'I' /*INSERO*/ BEGIN
         SET @V_DESC   = 'Filial '            + ISNULL(@V_NEW_CDFILIAL,''    )      +  ' '  + 
                     'Cd da Tabela de Preo ' + ISNULL(@V_NEW_CDTABEPREC,''  )      +  ' '  + 
                     'DTINIVGPREC'            + ISNULL(CONVERT(VARCHAR,@V_NEW_DTINIVGPREC),'' )      +  ' '  + 
		     'Cd Produto '            + ISNULL(@V_NEW_CDPRODUTO,''    )     +  ' '  + 
                     'CDPRPAITABPR'           + ISNULL(@V_NEW_CDPRPAITABPR,'' )     +  ' '  + 
                     'Nr do dia da Semana '   + ISNULL(@V_NEW_NRDIASEMANPR,''  )    +  ' '  + 
                     'Hr de Inicio Promoo ' + ISNULL(@V_NEW_HRINIPRECDIA,'' )     +  ' '  + 
                     'Cd Tipo de Consumidor ' + ISNULL(@V_NEW_CDTIPOCONSPD,''  )    +  ' '  + 
                     'Hr de Fim Promoo '    + ISNULL(@V_NEW_HRFINPRECDIA,'' )     +  ' '  + 
                     'Preo produto '         + ISNULL(CONVERT(VARCHAR,@V_NEW_VRPRECODIA),''    )    +  ' '  + 
                     'Id Valor '              + ISNULL(@V_NEW_IDPERVALORPR,''  )    +  ' '  + 
                     'Id Desconto '           + ISNULL(@V_NEW_IDDESCACREPR,'' )     +  ' '  +  
                     'Dt Inicio Validade '    + ISNULL(CONVERT(VARCHAR,@V_NEW_DTINIVALPREC),''    )  +  ' '  + 
                     'Dt Fim Validade '       + ISNULL(CONVERT(VARCHAR,@V_NEW_DTFINVALPREC),''  )    +  ' '  + 
                     'Dt Ult Atu do Preo '   + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUITPD),'' )     +  ' '  +  
                     'Id Visua Desc Cupom '   + ISNULL(@V_NEW_IDVISUACUPOM,'');
         SET @V_IDTIPOOPER = '1';
      END;
      IF @V_ID_COMANDO= 'D' /*DELEO*/  BEGIN
         SET @V_DESC   = 'Filial '            + ISNULL(@V_OLD_CDFILIAL,''    )      +  ' '  + 
                     'Cd da Tabela de Preo ' + ISNULL(@V_OLD_CDTABEPREC,''  )      +  ' '  + 
                     'DTINIVGPREC'            + ISNULL(CONVERT(VARCHAR,@V_OLD_DTINIVGPREC),'' )      +  ' '  + 
					 'Cd Produto '            + ISNULL(@V_OLD_CDPRODUTO,''    )     +  ' '  + 
                     'CDPRPAITABPR'           + ISNULL(@V_OLD_CDPRPAITABPR,'' )     +  ' '  + 
                     'Nr do dia da Semana '   + ISNULL(@V_OLD_NRDIASEMANPR,''  )    +  ' '  + 
                     'Hr de Inicio Promoo ' + ISNULL(@V_OLD_HRINIPRECDIA,'' )     +  ' '  + 
                     'Cd Tipo de Consumidor ' + ISNULL(@V_OLD_CDTIPOCONSPD,''  )    +  ' '  + 
                     'Hr de Fim Promoo '    + ISNULL(@V_OLD_HRFINPRECDIA,'' )     +  ' '  + 
					 'Preo produto '         + ISNULL(CONVERT(VARCHAR,@V_OLD_VRPRECODIA),''    )    +  ' '  + 
                     'Id Valor '              + ISNULL(@V_OLD_IDPERVALORPR,''  )    +  ' '  + 
                     'Id Desconto '           + ISNULL(@V_OLD_IDDESCACREPR,'' )     +  ' '  +  
					 'Dt Inicio Validade '    + ISNULL(CONVERT(VARCHAR,@V_OLD_DTINIVALPREC),''    )  +  ' '  + 
                     'Dt Fim Validade '       + ISNULL(CONVERT(VARCHAR,@V_OLD_DTFINVALPREC),''  )    +  ' '  + 
                     'Dt Ult Atu do Preo '   + ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATUITPD),'' )     +  ' '  +  
                     'Id Visua Desc Cupom '   + ISNULL(@V_OLD_IDVISUACUPOM,'');
         SET @V_IDTIPOOPER = '3';
      END;
      IF  (@V_IDTIPOOPER <> '') BEGIN
         IF @V_DESC IS NOT NULL BEGIN
             SET @V_ITPESQ =  ISNULL(@V_NEW_CDFILIAL + @V_NEW_CDTABEPREC + @V_NEW_CDPRODUTO + @V_NEW_CDPRPAITABPR + @V_NEW_NRDIASEMANPR + @V_NEW_HRINIPRECDIA + @V_NEW_CDTIPOCONSPD,
                                     @V_OLD_CDFILIAL + @V_OLD_CDTABEPREC + @V_OLD_CDPRODUTO + @V_OLD_CDPRPAITABPR + @V_OLD_NRDIASEMANPR + @V_OLD_HRINIPRECDIA + @V_OLD_CDTIPOCONSPD);
             SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
             INSERT INTO LOGOPERAVND
                    (NMTABELAVND, DTOPERACAOVND, NMRESPOPERVND, IDTIPOOPERVND, DSOPERACAOVND,
                     CDPESQITEMVND, DSRDMUSUOPERVND, DSENDUSUOPERVND, DSNMUSUOPERVND, DSMETUSUOPERVND,
                     CDORESPOPERVND, CDFILLOGOPERVND)
             VALUES ('ITEMPRECODIA',GETDATE(), ISNULL(@V_NMOPERADOR,' '), @V_IDTIPOOPER, @V_DESC, @V_ITPESQ,
                     @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER,
                     ISNULL(@V_NEW_CDFILIAL,@V_OLD_CDFILIAL));
         END;
      END;
      FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
           @V_NEW_CDFILIAL,@V_NEW_CDTABEPREC,@V_NEW_DTINIVGPREC,@V_NEW_CDPRODUTO,
           @V_NEW_CDPRPAITABPR,@V_NEW_NRDIASEMANPR,@V_NEW_HRINIPRECDIA,@V_NEW_CDTIPOCONSPD,
           @V_NEW_HRFINPRECDIA,@V_NEW_VRPRECODIA,@V_NEW_IDPERVALORPR,@V_NEW_IDDESCACREPR,
           @V_NEW_DTINIVALPREC,@V_NEW_DTFINVALPREC,@V_NEW_DTULTATUITPD,@V_NEW_IDVISUACUPOM,

           @V_OLD_CDFILIAL,@V_OLD_CDTABEPREC,@V_OLD_DTINIVGPREC,@V_OLD_CDPRODUTO,
           @V_OLD_CDPRPAITABPR,@V_OLD_NRDIASEMANPR,@V_OLD_HRINIPRECDIA,@V_OLD_CDTIPOCONSPD,
           @V_OLD_HRFINPRECDIA,@V_OLD_VRPRECODIA,@V_OLD_IDPERVALORPR,@V_OLD_IDDESCACREPR,
           @V_OLD_DTINIVALPREC,@V_OLD_DTFINVALPREC,@V_OLD_DTULTATUITPD,@V_OLD_IDVISUACUPOM
   SET @V_DESC       = '';
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_VND_ITEMPRECODIA','5.20.001';
GO 
