function LSSettingsController(LSUtilities, LSSettingsService, ScreenService, templateManager, MessageService, ApplicationContext, ZhFilterPreferences) {
    var FORM_TEMPLATE = 'widget/form.html';
    var FORM_VIEW_TEMPLATE = 'widget/form-view.html';
    var USE_AD_NEGATIVE = 'N';
    var USE_PASSWORD_CONTROL_NEGATIVE = 'N';
    var USE_AD_FIELD_NAME = 'USE_AD';

    var getContainer = function() {
        return templateManager.container;
    };
    
    var getActiveDirectoryWidget = function() {
        return getContainer().getWidget('ACTIVE_DIRECTORY');
    };
    
    var getWidgetOrganizationParameters = function(){
        return getContainer().getWidget('ORGANIZATION_PARAMETERS');
    };

    var getWidgetOrganizationRestrictionByIp = function(){
        return getContainer().getWidget('ORGANIZATION_RESTRICTION_BY_IP');
    };

    var getFieldIpv4FromOrganizationRestrictionByIpWidget = function(){
        return getWidgetOrganizationRestrictionByIp().getField('IPV4');
    };
    
    var getFieldIpv6FromOrganizationRestrictionByIpWidget = function(){
        return getWidgetOrganizationRestrictionByIp().getField('IPV6');
    };

    var reloadAndSetViewMode = function(widget, datasetResultPos, isSetCurrentRow) {
        datasetResultPos = datasetResultPos || 'adConfig';
        widget.list();
        widget.reload().then(function(response) {
            widget.template = FORM_VIEW_TEMPLATE;
            widget.view();
            if(isSetCurrentRow) {
                widget.setCurrentRow(response.dataset[datasetResultPos][0]);
            }
        });
    };

    var enableDisableFieldsByUseAd = function() {
        var activeDirectoryWidget = getActiveDirectoryWidget();
        var readOnly = activeDirectoryWidget.currentRow.USE_AD == USE_AD_NEGATIVE || !activeDirectoryWidget.currentRow.USE_AD;

        activeDirectoryWidget.fields.forEach(function(field) {
            if(field.name != USE_AD_FIELD_NAME) {
                field.readOnly = readOnly ;
                if(readOnly) {
                    field.setValue('');
                    field.validations = {};
                } else if(field.lsIsRequired){
                    field.validations = { required: true };
                }
            }
        });
    };

    this.settingsContainerAfterInit = function() {
        var activeDirectoryWidget = getActiveDirectoryWidget();
        activeDirectoryWidget.view();
        activeDirectoryWidget.activate();
    };

    this.activeDirectoryActionEventEdit = function() {
        var activeDirectoryWidget = getActiveDirectoryWidget();
        activeDirectoryWidget.template = FORM_TEMPLATE;
        activeDirectoryWidget.edit();
    };

    this.activeDirectoryActionEventBack = function() {
        ScreenService.goBack();
    };

    this.activeDirectoryActionEventConfirm = function() {
        var activeDirectoryWidget = getActiveDirectoryWidget();
        if(activeDirectoryWidget.isValid()) {
            activeDirectoryWidget.saveRow().then(function (response) {
                if (response && response.dataset) {
                    reloadAndSetViewMode(activeDirectoryWidget, 'adConfig', true);
                    MessageService.successNotificationByCode('login#SUC_AD_SETTINGS_UPDATED');
                }
            }).catch(LSUtilities.defaultError);
        }
    };

    this.activeDirectoryActionEventCancel = function() {
        reloadAndSetViewMode(getActiveDirectoryWidget(), 'adConfig', true);
    };
    
    this.organizationRestrictionByIpActionEventEdit = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        LSUtilities.setLocalVar("currentRow", widget.currentRow);
        widget.edit();
        changeToReadonlyFieldsIpv4OrIpv6();
    };
    
    this.organizationRestrictionByIpActionEventRemove = function(){
        MessageService.confirmMessageByCode('login#ALE_CONFIRM_REMOVE_REGISTER', null,
            {
                type: 'CONFIRMATION',
                success: removeOrganizationRestrictionByIp,
                fail: function () {}
            }
        );
    };

    this.activeDirectoryWidgetAfterLoadDataSource = function() {
        var activeDirectoryWidget = getActiveDirectoryWidget();
        activeDirectoryWidget.view();
        var data = activeDirectoryWidget.dataSource.data;
        activeDirectoryWidget.currentRow = data.length === 0 ? { USE_AD : USE_AD_NEGATIVE } : data[0];
        enableDisableFieldsByUseAd();
    };

    this.settingsFieldOnChangeUseAd = function() {
        enableDisableFieldsByUseAd();
    };
    
    this.activeDirectoryWidgetOnEnterTab = function(){
        checkIfOrganizationUseRestrictionByIp();
    };
    
    this.organizationRestrictionByIpWidgetOnEnterTab = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        if (!widget.DOInitFilter){
            widget.DOInitFilter = true;
            ZhFilterPreferences.setOriginalFilter(
                widget,
                {"ACTIVE": "S"}
            );
        }
        widget.reload();
    };
    
    this.organizationRestrictionByIpWidgetAfterMoveRow = function(){
        var fieldIpv4 = getFieldIpv4FromOrganizationRestrictionByIpWidget();
        var fieldIpv6 = getFieldIpv6FromOrganizationRestrictionByIpWidget();
        if (!fieldIpv4.value()){
            fieldIpv4.placeholder = '';
        } else if (!fieldIpv6.value()){
            fieldIpv6.placeholder = '';
        }
    };
    
    var removeOrganizationRestrictionByIp = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        widget.removeRow().then(function(){
            MessageService.successNotificationByCode('login#SUC_REMOVED');
            ScreenService.closeSwipe().then(function(){
                widget.reload();
                widget.activate();
                widget.list();
            });
        }).catch(LSUtilities.defaultError);
    };
    
    this.organizationRestrictionByIpActionEventCancel = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        if (typeof widget.currentRow.__is_new !== "undefined" && widget.currentRow.__is_new === true) {
            ScreenService.closeSwipe();
            widget.list();
        } else {
            widget.view();
            widget.currentRow = LSUtilities.getLocalVar('currentRow');
        }
        widget.reload();
        widget.activate();
    };
    
    this.organizationRestrictionByIpFieldOnChangeIpv4 = function(){
        changeToReadonlyFieldsIpv4OrIpv6();
    };
    
    this.organizationRestrictionByIpFieldOnChangeIpv6 = function(){
        changeToReadonlyFieldsIpv4OrIpv6();
    };
    
    var changeToReadonlyFieldsIpv4OrIpv6 = function(){
        var fieldIpv4 = getFieldIpv4FromOrganizationRestrictionByIpWidget();
        var fieldIpv6 = getFieldIpv6FromOrganizationRestrictionByIpWidget();
        if (fieldIpv4.value()){
            setReadonlyAndRemovePlaceholderFieldsIpv4OrIpv6(false, true);
        } else if (fieldIpv6.value()){
            setReadonlyAndRemovePlaceholderFieldsIpv4OrIpv6(true, false);
        } else {
            fieldIpv4.readOnly = false;
            fieldIpv6.readOnly = false;
            setExampleIpInFieldPlaceholder();
        }
    };
    
    var setReadonlyAndRemovePlaceholderFieldsIpv4OrIpv6 = function(ipv4Value, ipv6Value){
        getFieldIpv4FromOrganizationRestrictionByIpWidget().readOnly = ipv4Value;
        getFieldIpv6FromOrganizationRestrictionByIpWidget().readOnly = ipv6Value;
        removeExampleIpInFieldPlaceholder();
    };
    
    this.organizationRestrictionByIpActionEventSave = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        var currentRow = widget.currentRow;
        if (!widget.isValid()){
            return;
        }
        if (currentRow.IPV4 || currentRow.IPV6){
            LSSettingsService.saveRestrictionByIp(currentRow).then(function(restrictionId){
                currentRow.ID = restrictionId;
                currentRow.changed = false;
                currentRow.__is_new = false;
                widget.list();
                widget.reload();
    			widget.view();
    			widget.activate();
                MessageService.successNotificationByCode('login#SUC_SAVED');
            }).catch(LSUtilities.defaultError);
        } else {
            MessageService.showMessageByCode('login#ALE_NONE_IP_INFORMED', null, { type: 'ALERT' });
        }
    };
    
    this.organizationRestrictionByIpActionEventAdd = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        widget.newRow();
        changeToReadonlyFieldsIpv4OrIpv6();
        cleanWidgetDescriptionOrder(widget);
    };
    
    var cleanWidgetDescriptionOrder = function(widget){
        widget.descriptionOrder = '';
    };
    
    var removeExampleIpInFieldPlaceholder = function(){
        getFieldIpv4FromOrganizationRestrictionByIpWidget().placeholder = '';
        getFieldIpv6FromOrganizationRestrictionByIpWidget().placeholder = '';
    };
    
    var setExampleIpInFieldPlaceholder = function(){
        getFieldIpv4FromOrganizationRestrictionByIpWidget().placeholder = '192.168.254.254';
        getFieldIpv6FromOrganizationRestrictionByIpWidget().placeholder = '2001:0DB8:00AD:000F:0000:0000:0000:0001';
    };
    
    var checkIfOrganizationUseRestrictionByIp = function(){
        var widget = getWidgetOrganizationRestrictionByIp();
        LSSettingsService.getOrganizationParameters().then(function(parameter){
            if (parameter == 'S'){
                 widget.enabled = true;
            } else {
                widget.enabled = false;
                if (widget.isActive()){
                    getWidgetOrganizationParameters().activate();
                }
            }
        });
    };

    this.organizationRestrictionByIpActionEventBackView = function(){
        ScreenService.closeSwipe().then(function() {
            getWidgetOrganizationRestrictionByIp().list();
            getWidgetOrganizationRestrictionByIp().reload();
        });  
    };

    this.organizationParametersActionEventEdit = function() {
        var widget = getWidgetOrganizationParameters();
        widget.template = FORM_TEMPLATE;
        widget.edit();
        enableDisableFieldsByUsePasswordControl(false);
    };

    this.organizationParametersActionEventCancel = function() {
        var widget = getWidgetOrganizationParameters();
        widget.reload();
        widget.template = FORM_VIEW_TEMPLATE;
        widget.view();
    };

    this.organizationParametersActionEventSave = function() {
        var widget = getWidgetOrganizationParameters();
        if(widget.isValid()) {
            widget.saveRow().then(function () {
                reloadAndSetViewMode(widget, undefined, false);
                getWidgetOrganizationRestrictionByIp().enabled = widget.currentRow.USE_RESTRICTION == 'S';
                MessageService.successNotificationByCode('login#SUC_PARAMETER_SAVED');
            }).catch(LSUtilities.defaultError);
        }
    };

    this.organizationParametersWidgetAfterLoadDataSource = function() {
        getWidgetOrganizationParameters().moveToFirst();
    };

    this.organizationParametersWidgetOnEnter = function() {
        getWidgetOrganizationParameters().reload();
    };

    this.organizationParametersFieldOnChangeIdUtCtrlSen = function() {
        enableDisableFieldsByUsePasswordControl(true);
    };

    var enableDisableFieldsByUsePasswordControl = function(isOnChange) {
        var widget = getWidgetOrganizationParameters();
        var usePasswordControl = widget.currentRow.IDUTCTRLSEN;
        widget.fields.forEach(function(field) {
            if(field.isPasswordControl) {
                field.readOnly = usePasswordControl == USE_PASSWORD_CONTROL_NEGATIVE;
                if(isOnChange) {
                    field.value('');
                }
            }
        });
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('LSSettingsController', LSSettingsController);
});